'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var STATUS_CHANNEL = 'Breakfast::StatusChannel';

var StatusBar = function () {
  function StatusBar() {
    var _this = this;

    var settings = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, StatusBar);

    this.settings = settings;

    this.settings.cable.subscriptions.create(STATUS_CHANNEL, {
      connected: function connected() {
        _this.write(_this.settings.log.message, _this.settings.log.status);
      },
      received: function received(log) {
        if (_this.settings.strategies[log.extension] !== 'off') {
          _this.settings.updateLog(log);
          _this.write(log.message, log.status);
        }
      },
      disconnected: function disconnected() {
        _this.write('Disconnected from server...', 'error');
      }
    });
  }

  _createClass(StatusBar, [{
    key: 'init',
    value: function init() {
      var _this2 = this;

      var eventName = void 0;

      if (typeof Turbolinks !== 'undefined') {
        eventName = 'turbolinks:load';
      } else {
        eventName = 'DOMContentLoaded';
      }

      document.addEventListener(eventName, function () {
        _this2.render();
        _this2.write(_this2.settings.log.message, _this2.settings.log.status);
      });

      window.Breakfast.StatusBar = this;
    }
  }, {
    key: 'write',
    value: function write(message, status) {
      var log = document.getElementById('breakfast-message-log');
      if (log) {
        log.innerHTML = message;
        log.className = 'breakfast-message-log-' + status;
      }
    }
  }, {
    key: 'handleClick',
    value: function handleClick(option) {
      this.settings.updateStrategies(option);
      var reloaders = document.getElementById('breakfast-reloaders');
      reloaders.innerHTML = this.renderReloaders();
    }
  }, {
    key: 'render',
    value: function render() {
      var statusBar = document.getElementById('breakfast-status-bar');

      if (statusBar) {
        document.body.removeChild(statusBar);
      }

      var sb = document.createElement('DIV');
      sb.setAttribute('class', 'breakfast-status-bar');
      sb.setAttribute('id', 'breakfast-status-bar');

      sb.innerHTML = '\n      ' + this.stylesheet() + '\n      <div id="breakfast-reloaders" class="breakfast-reloaders">\n        ' + this.renderReloaders() + '\n      </div>\n      <div id="breakfast-message-log">\n      </div>\n   ';

      document.body.appendChild(sb);
    }
  }, {
    key: 'renderReloaders',
    value: function renderReloaders() {
      return '\n      <div class="breakfast-reloader">\n        <span>js: </span><span class="breakfast-type">' + this.settings.strategies.js + '</span>\n        <div class="breakfast-menu">\n          ' + this.renderLink('js', 'page', 'Page Reload') + '\n          ' + this.renderLink('js', 'off', 'Off') + '\n        </div>\n      </div>\n\n      <div class="breakfast-reloader">\n        <span>css: </span><span class="breakfast-type">' + this.settings.strategies.css + '</span>\n        <div class="breakfast-menu">\n          ' + this.renderLink('css', 'page', 'Page Reload') + '\n          ' + this.renderLink('css', 'hot', 'Hot Reload') + '\n          ' + this.renderLink('css', 'off', 'Off') + '\n        </div>\n      </div>\n      <div class="breakfast-reloader">\n        <span>html: </span><span class="breakfast-type">' + this.settings.strategies.html + '</span>\n        <div class="breakfast-menu">\n          ' + this.renderLink('html', 'page', 'Page Reload') + '\n          ' + this.renderLink('html', 'turbolinks', 'Turbolinks Reload') + '\n          ' + this.renderLink('html', 'off', 'Off') + '\n        </div>\n      </div>\n\n      <div class="breakfast-reloader">\n        <span>ruby: </span><span class="breakfast-type">' + this.settings.strategies.rb + '</span>\n        <div class="breakfast-menu">\n          ' + this.renderLink('rb', 'page', 'Page Reload') + '\n          ' + this.renderLink('rb', 'turbolinks', 'Turbolinks Reload') + '\n          ' + this.renderLink('rb', 'off', 'Off') + '\n        </div>\n      </div>\n    ';
    }
  }, {
    key: 'renderLink',
    value: function renderLink(type, strategy, text) {
      var active = this.settings.strategies[type] === strategy;

      return '\n      <a\n        class="breakfast-menu-option ' + (active ? 'breakfast-active' : '') + '"\n        onclick="Breakfast.StatusBar.handleClick({\'' + type + '\': \'' + strategy + '\'}); return false;"\n        href="#"\n      >\n        <div class="breakfast-toggle"></div><div>' + text + '</div>\n      </a>\n    ';
    }
  }, {
    key: 'stylesheet',
    value: function stylesheet() {
      return '\n      <style>\n        .breakfast-status-bar {\n          align-items: center;\n          background-color: #1f1f1f;\n          ' + this.settings.statusBarLocation + ': 0;\n          color: #999;\n          font-family: monospace;\n          font-size: 12px;\n          display: flex;\n          height: 30px;\n          position: fixed;\n          width: 100%;\n        }\n\n        .breakfast-status-bar .breakfast-reloaders {\n          align-items: center;\n          display: flex;\n        }\n\n        .breakfast-status-bar .breakfast-reloader {\n          border-left: 1px solid #444;\n          padding: 4px 8px;\n          position: relative;\n        }\n\n        .breakfast-status-bar .breakfast-reloader:hover {\n          cursor: pointer;\n        }\n\n        .breakfast-status-bar .breakfast-reloader:hover .breakfast-menu {\n          display: block;\n        }\n\n        .breakfast-status-bar .breakfast-type {\n          color: #eee;\n        }\n\n        .breakfast-status-bar .breakfast-menu {\n          background-color: #1f1f1f;\n          border-radius: 2px;\n          ' + this.settings.statusBarLocation + ': 22px;\n          display: none;\n          left: 0;\n          position: absolute;\n          width: 225px;\n        }\n\n        .breakfast-status-bar .breakfast-menu-option {\n          align-items: center;\n          border-bottom: 1px solid #000;\n          border-top: 1px solid #333;\n          color: #999;\n          display: flex;\n          padding: 6px 15px;\n          z-index: 1000;\n        }\n\n        .breakfast-status-bar .breakfast-menu-option:hover {\n          background-color: #333;\n          text-decoration: none;\n        }\n\n        .breakfast-status-bar .breakfast-active {\n          color: #eee;\n        }\n\n        .breakfast-status-bar .breakfast-active .breakfast-toggle {\n          background-color: #539417;\n        }\n\n        .breakfast-status-bar .breakfast-toggle {\n          background-color: #000;\n          border-radius: 50%;\n          height: 8px;\n          margin-right: 8px;\n          width: 8px;\n        }\n\n        .breakfast-status-bar .breakfast-message-log-success {\n          align-items: center;\n          background-color: #539417;\n          color: #fff;\n          display: flex;\n          flex-grow: 1;\n          height: 30px;\n          padding: 0 8px;\n        }\n\n        .breakfast-status-bar .breakfast-message-log-error {\n          align-self: ' + (this.settings.statusBarLocation === 'bottom' ? 'flex-end' : 'flex-start') + ';\n          background-color: #a93131;\n          color: #fff;\n          flex-grow: 1;\n          min-height: 30px;\n          padding: 5px 8px;\n          white-space: pre-wrap;\n        }\n      </style>\n    ';
    }
  }]);

  return StatusBar;
}();

module.exports = StatusBar;